@@ -18,7 +18,7 @@ ts_conv1d <- function(preprocess = NA, input_size = NA, epochs = 10000L) {
   return(obj)
 }
 
-#'@export
+#'@exportS3Method do_fit ts_conv1d
 do_fit.ts_conv1d <- function(obj, x, y) {
   reticulate::source_python(system.file("python", "ts_conv1d.py", package = "daltoolbox"))
 
@@ -33,7 +33,7 @@ do_fit.ts_conv1d <- function(obj, x, y) {
   return(obj)
 }
 
-#'@export
+#'@exportS3Method do_predict ts_conv1d
 do_predict.ts_conv1d <- function(obj, x) {
   reticulate::source_python(system.file("python", "ts_conv1d.py", package = "daltoolbox"))
 
@@ -41,16 +41,6 @@ do_predict.ts_conv1d <- function(obj, x) {
   X_values$t0 <- 0
 
   n <- nrow(X_values)
-  if (n > 1) {
-    prediction <- ts_conv1d_predict(obj$model, X_values)
-    prediction <-unlist(prediction$tolist())
-  }
-  else if (n == 1) {
-    X_values <- rbind(X_values,X_values)
-    prediction <- ts_conv1d_predict(obj$model, X_values)
-    prediction <-unlist(prediction$tolist())[1]
-  }
-  else
-    prediction <- NA
+  prediction <- ts_conv1d_predict(obj$model, X_values)
   return(prediction)
 }
